@@ -1,5 +1,5 @@
 /*
- * Copyright 2006 Computing Research Labs, New Mexico State University
+ * Copyright 2008 Department of Mathematical Sciences, New Mexico State University
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -14,25 +14,16 @@
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
- * THE COMPUTING RESEARCH LAB OR NEW MEXICO STATE UNIVERSITY BE LIABLE FOR ANY
- * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT
- * OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR
- * THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+ * DEPARTMENT OF MATHEMATICAL SCIENCES OR NEW MEXICO STATE UNIVERSITY BE
+ * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+ * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+ * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
-
 /*
  * Only compile this if the FreeType library is available.
  */
 #ifdef HAVE_FREETYPE
 
-#ifndef lint
-#ifdef __GNUC__
-static char svnid[] __attribute__ ((unused)) = "$Id: bdfotf.c 5 2006-01-08 01:39:22Z mleisher $";
-#else
-static char svnid[] = "$Id: bdfotf.c 5 2006-01-08 01:39:22Z mleisher $";
-#endif
-#endif
-
 #include "bdfP.h"
 #include FT_GLYPH_H
 #include FT_SFNT_NAMES_H
@@ -250,10 +241,10 @@ _bdfotf_generate(FT_Face face, int nocmap, bdf_options_t *opts,
                  bdf_callback_t callback, void *data, bdf_font_t *fp)
 {
     int ismono;
-    long awidth, code, idx;
+    int awidth, code, idx;
     short maxrb, maxlb, minlb, y, x;
     short x_off, y_off, maxas, maxds;
-    unsigned short upm, bpr, wd, ht, sx, ex, sy, ey;
+    int upm, bpr, wd, ht, sx, ex, sy, ey;
     unsigned char *bmap;
     bdf_glyph_t *gp;
     double swscale;
@@ -442,7 +433,7 @@ _bdfotf_generate(FT_Face face, int nocmap, bdf_options_t *opts,
      * Calculate the font average width.
      */
     awidth =
-        (long) ((((double) awidth / (double) fp->glyphs_used) + 0.5) * 10.0);
+        (int) ((((double) awidth / (double) fp->glyphs_used) + 0.5) * 10.0);
 
     /*
      * Set the font bounding box.
@@ -480,19 +471,19 @@ _bdfotf_generate(FT_Face face, int nocmap, bdf_options_t *opts,
 
     prop.name = "PIXEL_SIZE";
     prop.format = BDF_INTEGER;
-    prop.value.int32 = (long)
+    prop.value.int32 = (int)
         ((((double) (fp->point_size * 10) *
            (double) fp->resolution_y) / 722.7) + 0.5);
     bdf_add_font_property(fp, &prop);
 
     prop.name = "RESOLUTION_X";
     prop.format = BDF_CARDINAL;
-    prop.value.card32 = (unsigned long) fp->resolution_x;
+    prop.value.card32 = (unsigned int) fp->resolution_x;
     bdf_add_font_property(fp, &prop);
 
     prop.name = "RESOLUTION_Y";
     prop.format = BDF_CARDINAL;
-    prop.value.card32 = (unsigned long) fp->resolution_y;
+    prop.value.card32 = (unsigned int) fp->resolution_y;
     bdf_add_font_property(fp, &prop);
 
     prop.name = "FONT_ASCENT";
