@@ -1,5 +1,5 @@
 /*
- * Copyright 2006 Computing Research Labs, New Mexico State University
+ * Copyright 2008 Department of Mathematical Sciences, New Mexico State University
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -14,18 +14,11 @@
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
- * THE COMPUTING RESEARCH LAB OR NEW MEXICO STATE UNIVERSITY BE LIABLE FOR ANY
- * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT
- * OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR
- * THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+ * DEPARTMENT OF MATHEMATICAL SCIENCES OR NEW MEXICO STATE UNIVERSITY BE
+ * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+ * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+ * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
-#ifndef lint
-#ifdef __GNUC__
-static char svnid[] __attribute__ ((unused)) = "$Id: guigedit.c 64 2006-09-11 16:39:52Z mleisher $";
-#else
-static char svnid[] = "$Id: guigedit.c 64 2006-09-11 16:39:52Z mleisher $";
-#endif
-#endif
 
 #include "gbdfed.h"
 #include "glyphedit.h"
@@ -266,6 +259,10 @@ typedef struct {
     GtkWidget *update_prev;
     GtkWidget *update_next;
 
+    GtkWidget *button_update;
+    GtkWidget *button_prev;
+    GtkWidget *button_next;
+
     GtkWidget *edit_menu;
     GtkWidget *reload;
     GtkWidget *resize;
@@ -413,6 +410,12 @@ update_font(GtkWidget *w, gpointer data)
     gtk_widget_set_sensitive(ge->update, FALSE);
     gtk_widget_set_sensitive(ge->update_next, FALSE);
     gtk_widget_set_sensitive(ge->update_prev, FALSE);
+    gtk_widget_set_sensitive(ge->button_update, FALSE);
+
+    /*
+     * Force the focus to be on the glyph grid
+     */
+    gtk_widget_grab_focus(ge->gedit);
 }
 
 /*
@@ -421,15 +424,18 @@ update_font(GtkWidget *w, gpointer data)
 static void
 update_glyphedit(gbdfed_editor_t *ed, GlypheditRec *ge, bdf_glyph_grid_t *grid)
 {
+    Glyphedit *gw;
+
+    gw = GLYPHEDIT(ge->gedit);
     gtk_entry_set_text(GTK_ENTRY(ge->name), grid->name);
 
     if (grid->unencoded)
       sprintf(buffer1, "-1");
     else {
         switch (fontgrid_get_code_base(FONTGRID(ed->fgrid))) {
-          case 8: sprintf(buffer1, "%lo", grid->encoding); break;
-          case 10: sprintf(buffer1, "%ld", grid->encoding); break;
-          case 16: sprintf(buffer1, "%04lX", grid->encoding); break;
+          case 8: sprintf(buffer1, "%o", grid->encoding); break;
+          case 10: sprintf(buffer1, "%d", grid->encoding); break;
+          case 16: sprintf(buffer1, "%04X", grid->encoding); break;
         }
     }
     gtk_label_set_text(GTK_LABEL(ge->encoding), buffer1);
@@ -455,7 +461,7 @@ update_glyphedit(gbdfed_editor_t *ed, GlypheditRec *ge, bdf_glyph_grid_t *grid)
     /*
      * Set the new grid in the glyph editor.
      */
-    glyphedit_set_grid(GLYPHEDIT(ge->gedit), grid);
+    glyphedit_set_grid(gw, grid);
 
     /*
      * Set the sensitivity of the update menu items appropriately.
@@ -464,11 +470,28 @@ update_glyphedit(gbdfed_editor_t *ed, GlypheditRec *ge, bdf_glyph_grid_t *grid)
         gtk_widget_set_sensitive(ge->update, TRUE);
         gtk_widget_set_sensitive(ge->update_next, TRUE);
         gtk_widget_set_sensitive(ge->update_prev, TRUE);
+	gtk_widget_set_sensitive(ge->button_update, TRUE);
     } else {
         gtk_widget_set_sensitive(ge->update, FALSE);
         gtk_widget_set_sensitive(ge->update_next, FALSE);
         gtk_widget_set_sensitive(ge->update_prev, FALSE);
+	gtk_widget_set_sensitive(ge->button_update, FALSE);
     }
+
+    if (glyphedit_get_encoding(gw) == 0)
+      gtk_widget_set_sensitive(ge->button_prev, FALSE);
+    else
+      gtk_widget_set_sensitive(ge->button_prev, TRUE);
+
+    if (glyphedit_get_encoding(gw) == 0xffff)
+      gtk_widget_set_sensitive(ge->button_next, FALSE);
+    else
+      gtk_widget_set_sensitive(ge->button_next, TRUE);
+
+    /*
+     * Force the focus to be on the glyph grid.
+     */
+    gtk_widget_grab_focus(ge->gedit);
 }
 
 static void
@@ -487,7 +510,7 @@ next_glyph(GtkWidget *w, gpointer data)
 
     grid = glyphedit_get_grid(GLYPHEDIT(ge->gedit));
 
-    if (fontgrid_select_next_glyph(FONTGRID(ed->fgrid)) == FALSE)
+    if (fontgrid_select_next_glyph(FONTGRID(ed->fgrid), grid->encoding) == FALSE)
       return;
 
     font = fontgrid_get_font(FONTGRID(ed->fgrid));
@@ -521,7 +544,7 @@ previous_glyph(GtkWidget *w, gpointer data)
 
     grid = glyphedit_get_grid(GLYPHEDIT(ge->gedit));
 
-    if (fontgrid_select_previous_glyph(FONTGRID(ed->fgrid)) == FALSE)
+    if (fontgrid_select_previous_glyph(FONTGRID(ed->fgrid), grid->encoding) == FALSE)
       return;
 
     font = fontgrid_get_font(FONTGRID(ed->fgrid));
@@ -683,9 +706,6 @@ static gboolean
 edit_menu_down(GtkWidget *w, GdkEvent *event, gpointer data)
 {
     GlypheditRec *ge = glyph_editors + GPOINTER_TO_UINT(data);
-    Glyphedit *gw;
-
-    gw = GLYPHEDIT(ge->gedit);
 
     gtk_widget_set_sensitive(ge->paste, TRUE);
     gtk_widget_set_sensitive(ge->copy, TRUE);
@@ -1142,8 +1162,12 @@ delete_unimap(GtkWidget *w, gpointer data)
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(ge->ops.psf_mappings));
     sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(ge->ops.psf_mappings));
 
-    if (gtk_tree_selection_get_selected(sel, 0, &iter))
-      gtk_list_store_remove(GTK_LIST_STORE(model), &iter);
+    if (gtk_tree_selection_get_selected(sel, 0, &iter)) {
+        gtk_list_store_remove(GTK_LIST_STORE(model), &iter);
+        ge->ops.psf_modified = TRUE;
+        gtk_widget_set_sensitive(ge->ops.psf_add, FALSE);
+        gtk_widget_set_sensitive(ge->ops.apply, TRUE);
+    }
 }
 
 static void
@@ -1293,7 +1317,7 @@ operations_dialog_setup(GlypheditRec *ge)
      * until we explicitly get rid of it later.
      */
     g_object_ref(G_OBJECT(ge->ops.rotate_adj));
-    gtk_object_sink(GTK_OBJECT(ge->ops.rotate_adj));
+    /*gtk_object_sink(GTK_OBJECT(ge->ops.rotate_adj));*/
 
     ge->ops.shear_adj =
         (GtkAdjustment *) gtk_adjustment_new(0.0, -20.0, 20.0, 1.0,
@@ -1303,7 +1327,7 @@ operations_dialog_setup(GlypheditRec *ge)
      * until we explicitly get rid of it later.
      */
     g_object_ref(G_OBJECT(ge->ops.shear_adj));
-    gtk_object_sink(GTK_OBJECT(ge->ops.shear_adj));
+    /*gtk_object_sink(GTK_OBJECT(ge->ops.shear_adj));*/
 
     hbox = gtk_hbox_new(FALSE, 0);
     label = gtk_label_new("Degrees:");
@@ -1316,7 +1340,7 @@ operations_dialog_setup(GlypheditRec *ge)
                                      "digits", 0,
                                      "value", 0.0,
                                      "numeric", TRUE,
-                                     0);
+                                     NULL);
     g_signal_connect(G_OBJECT(ge->ops.degrees), "changed",
                      G_CALLBACK(degrees_changed), GUINT_TO_POINTER(ge->id));
 
@@ -1402,7 +1426,7 @@ operations_dialog_setup(GlypheditRec *ge)
 
 
     cell_renderer = gtk_cell_renderer_text_new();
-    g_object_set(G_OBJECT(cell_renderer), "editable", TRUE, (void *) 0);
+    g_object_set(G_OBJECT(cell_renderer), "editable", TRUE, NULL);
     g_signal_connect_object(G_OBJECT(cell_renderer), "edited",
                             G_CALLBACK(change_unimap), (gpointer) store,
                             G_CONNECT_SWAPPED);
@@ -1430,7 +1454,7 @@ operations_dialog_setup(GlypheditRec *ge)
                      G_CALLBACK(add_mapping), GUINT_TO_POINTER(ge->id));
 
     ge->ops.psf_input = gtk_widget_new(gtk_entry_get_type(),
-                                       "max_length", 8, 0);
+                                       "max_length", 8, NULL);
     g_signal_connect(G_OBJECT(ge->ops.psf_input), "activate",
                      G_CALLBACK(add_mapping), GUINT_TO_POINTER(ge->id));
     g_signal_connect(G_OBJECT(ge->ops.psf_input), "changed",
@@ -1736,6 +1760,9 @@ glyph_modified(GtkWidget *w, gpointer cb, gpointer ged)
     gtk_widget_set_sensitive(ge->update, TRUE);
     gtk_widget_set_sensitive(ge->update_next, TRUE);
     gtk_widget_set_sensitive(ge->update_prev, TRUE);
+    gtk_widget_set_sensitive(ge->button_update, TRUE);
+    gtk_widget_set_sensitive(ge->button_next, TRUE);
+    gtk_widget_set_sensitive(ge->button_prev, TRUE);
 }
 
 /*
@@ -1826,13 +1853,14 @@ enable_update(GtkWidget *w, gpointer data)
     gtk_widget_set_sensitive(ge->update, TRUE);
     gtk_widget_set_sensitive(ge->update_next, TRUE);
     gtk_widget_set_sensitive(ge->update_prev, TRUE);
+    gtk_widget_set_sensitive(ge->button_update, TRUE);
 }
 
 static void
 _guigedit_build_editor(GlypheditRec *ge, bdf_glyph_grid_t *grid, guint base,
                        gbdfed_editor_t *ed)
 {
-    GtkWidget *mb, *mitem, *frame, *vbox, *vbox1, *hbox;
+    GtkWidget *mb, *mitem, *frame, *vbox, *vbox1, *hbox, *img;
     bdf_bitmap_t image;
 
     if (ed->file == 0)
@@ -1877,7 +1905,7 @@ _guigedit_build_editor(GlypheditRec *ge, bdf_glyph_grid_t *grid, guint base,
     gtk_window_add_accel_group(GTK_WINDOW(ge->shell), ge->ag);
 
     /*
-     * 1. Add the glyph name and encoding widgets.
+     * 1. Add the glyph name, next/previous buttons and encoding widgets.
      */
     frame = gtk_frame_new(0);
     gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_OUT);
@@ -1886,11 +1914,43 @@ _guigedit_build_editor(GlypheditRec *ge, bdf_glyph_grid_t *grid, guint base,
     vbox1 = gtk_vbox_new(TRUE, 0);
     gtk_container_add(GTK_CONTAINER(frame), vbox1);
 
-    ge->name = gtk_widget_new(gtk_entry_get_type(),
-                              "max_length", 128, 0);
-    mitem = labcon_new_label_defaults("Glyph Name:", ge->name, 0);
-    gtk_box_pack_start(GTK_BOX(vbox1), mitem, TRUE, TRUE, 0);
+    hbox = gtk_hbox_new(FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(vbox1), hbox, TRUE, TRUE, 0);
 
+    ge->name = gtk_widget_new(gtk_entry_get_type(), "max_length", 128, NULL);
+    mitem = labcon_new_label_defaults("Glyph Name:", ge->name, 0);
+    gtk_box_pack_start(GTK_BOX(hbox), mitem, TRUE, TRUE, 0);
+
+    /* Update button */
+    ge->button_update = gtk_button_new();
+    guiutil_util_set_tooltip(ge->button_update, "Update Font");
+    img = gtk_image_new_from_stock(GTK_STOCK_APPLY, GTK_ICON_SIZE_SMALL_TOOLBAR);
+    gtk_button_set_image(GTK_BUTTON(ge->button_update), img);
+    g_signal_connect(G_OBJECT(ge->button_update), "clicked", 
+		     G_CALLBACK(update_font), NULL);
+    gtk_box_pack_start(GTK_BOX(hbox), ge->button_update, FALSE, FALSE, 0);
+
+    /* Previous button */
+    ge->button_prev = gtk_button_new();
+    guiutil_util_set_tooltip(ge->button_prev, "Previous Glyph");
+    img = gtk_image_new_from_stock(GTK_STOCK_MEDIA_PREVIOUS, 
+		                   GTK_ICON_SIZE_SMALL_TOOLBAR);
+    gtk_button_set_image(GTK_BUTTON(ge->button_prev), img);
+    g_signal_connect(G_OBJECT(ge->button_prev), "clicked",
+		     G_CALLBACK(previous_glyph), NULL);
+    gtk_box_pack_start(GTK_BOX(hbox), ge->button_prev, FALSE, FALSE, 0);
+
+    /* Next button */
+    ge->button_next = gtk_button_new();
+    guiutil_util_set_tooltip(ge->button_next, "Next Glyph");
+    img = gtk_image_new_from_stock(GTK_STOCK_MEDIA_NEXT, 
+		                   GTK_ICON_SIZE_SMALL_TOOLBAR);
+    gtk_button_set_image(GTK_BUTTON(ge->button_next), img);
+    g_signal_connect(G_OBJECT(ge->button_next), "clicked", 
+		     G_CALLBACK(next_glyph), NULL);
+    gtk_box_pack_start(GTK_BOX(hbox), ge->button_next, FALSE, FALSE, 0);
+
+    /* Encoding */
     ge->encoding = gtk_label_new("0000");
     gtk_misc_set_alignment(GTK_MISC(ge->encoding), 0.0, 0.5);
     mitem = labcon_new_label_defaults("Encoding:", ge->encoding, mitem);
@@ -1908,7 +1968,7 @@ _guigedit_build_editor(GlypheditRec *ge, bdf_glyph_grid_t *grid, guint base,
 
     ge->dwidth = gtk_widget_new(gtk_entry_get_type(),
                                 "max_length", 6,
-                                0);
+                                NULL);
     ge->handler = g_signal_connect(G_OBJECT(ge->dwidth), "changed",
                                    G_CALLBACK(enable_update),
                                    GUINT_TO_POINTER(ge->id));
@@ -2027,9 +2087,9 @@ guigedit_edit_glyph(gbdfed_editor_t *ed, FontgridSelectionInfo *si)
       sprintf(buffer1, "-1");
     else {
         switch (base) {
-          case 8: sprintf(buffer1, "%lo", grid->encoding); break;
-          case 10: sprintf(buffer1, "%ld", grid->encoding); break;
-          case 16: sprintf(buffer1, "%04lX", grid->encoding); break;
+          case 8: sprintf(buffer1, "%o", grid->encoding); break;
+          case 10: sprintf(buffer1, "%d", grid->encoding); break;
+          case 16: sprintf(buffer1, "%04X", grid->encoding); break;
         }
     }
     gtk_label_set_text(GTK_LABEL(ge->encoding), buffer1);
@@ -2051,14 +2111,29 @@ guigedit_edit_glyph(gbdfed_editor_t *ed, FontgridSelectionInfo *si)
 
     if (grid->modified) {
         gtk_widget_set_sensitive(ge->update, TRUE);
+        gtk_widget_set_sensitive(ge->button_update, TRUE);
         gtk_widget_set_sensitive(ge->update_next, TRUE);
         gtk_widget_set_sensitive(ge->update_prev, TRUE);
     } else {
         gtk_widget_set_sensitive(ge->update, FALSE);
+        gtk_widget_set_sensitive(ge->button_update, FALSE);
         gtk_widget_set_sensitive(ge->update_next, FALSE);
         gtk_widget_set_sensitive(ge->update_prev, FALSE);
     }
 
+    /*
+     * Set the sensitivity of the next and previous buttons.
+     */
+    if (glyphedit_get_encoding(GLYPHEDIT(ge->gedit)) == 0)
+      gtk_widget_set_sensitive(ge->button_prev, FALSE);
+    else
+      gtk_widget_set_sensitive(ge->button_prev, TRUE);
+
+    if (glyphedit_get_encoding(GLYPHEDIT(ge->gedit)) == 0xffff)
+      gtk_widget_set_sensitive(ge->button_next, FALSE);
+    else
+      gtk_widget_set_sensitive(ge->button_next, TRUE);
+
     gtk_widget_show_all(ge->shell);
 
     /*
@@ -2132,20 +2207,20 @@ guigedit_set_font_spacing(gint spacing, guint16 monowidth)
 void
 guigedit_set_code_base(gint base)
 {
-    gulong i, enc;
+    guint i, enc;
 
     for (i = 0; i < num_glyph_editors; i++) {
         if (glyph_editors[i].owner != ~0) {
-            enc = (gulong) glyphedit_get_encoding(GLYPHEDIT(glyph_editors[i].gedit));
+            enc = (guint) glyphedit_get_encoding(GLYPHEDIT(glyph_editors[i].gedit));
             switch (base) {
               case 8:
-                sprintf(buffer1, "%lo", enc);
+                sprintf(buffer1, "%o", enc);
                 break;
               case 10:
-                sprintf(buffer1, "%ld", enc);
+                sprintf(buffer1, "%d", enc);
                 break;
               case 16:
-                sprintf(buffer1, "%04lX", enc);
+                sprintf(buffer1, "%04X", enc);
                 break;
             }
             gtk_label_set_text(GTK_LABEL(glyph_editors[i].encoding), buffer1);
