@@ -1,5 +1,5 @@
 /*
- * Copyright 2006 Computing Research Labs, New Mexico State University
+ * Copyright 2008 Department of Mathematical Sciences, New Mexico State University
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -14,18 +14,11 @@
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
- * THE COMPUTING RESEARCH LAB OR NEW MEXICO STATE UNIVERSITY BE LIABLE FOR ANY
- * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT
- * OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR
- * THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+ * DEPARTMENT OF MATHEMATICAL SCIENCES OR NEW MEXICO STATE UNIVERSITY BE
+ * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+ * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+ * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
-#ifndef lint
-#ifdef __GNUC__
-static char svnid[] __attribute__ ((unused)) = "$Id: guipref.c 64 2006-09-11 16:39:52Z mleisher $";
-#else
-static char svnid[] = "$Id: guipref.c 64 2006-09-11 16:39:52Z mleisher $";
-#endif
-#endif
 
 #include "gbdfed.h"
 #include "grayswatch.h"
@@ -81,7 +74,7 @@ pref_toggle(GtkWidget *w, gpointer data)
         tmp_opts.really_exit = val;
         break;
       case 10:
-        tmp_opts.pixel_size = (unsigned long)
+        tmp_opts.pixel_size = (unsigned int)
             gtk_combo_box_get_active(GTK_COMBO_BOX(w)) + 2;
         break;
     }
@@ -229,9 +222,9 @@ pref_change_size(GtkWidget *w, gpointer data)
     v = (gint) gtk_spin_button_get_value(GTK_SPIN_BUTTON(w));
 
     switch (which) {
-      case 0: tmp_opts.font_opts.point_size = (long) v; break;
-      case 1: tmp_opts.font_opts.resolution_x = (long) v; break;
-      case 2: tmp_opts.font_opts.resolution_y = (long) v; break;
+      case 0: tmp_opts.font_opts.point_size = (int) v; break;
+      case 1: tmp_opts.font_opts.resolution_x = (int) v; break;
+      case 2: tmp_opts.font_opts.resolution_y = (int) v; break;
     }
 
     /*
@@ -365,7 +358,7 @@ pref_select_colors(GtkWidget *w, gpointer data)
                                GTK_STOCK_REVERT_TO_SAVED,
                                GTK_RESPONSE_REJECT,
                                GTK_STOCK_CLOSE,
-                               GTK_RESPONSE_CLOSE, (void *) 0);
+                               GTK_RESPONSE_CLOSE, NULL);
 
         gtk_dialog_set_default_response(GTK_DIALOG(pref_color_dialog),
                                         GTK_RESPONSE_CLOSE);
@@ -657,7 +650,8 @@ pref_set_filename(GtkWidget *w, gpointer data)
 {
     gchar *fname;
 
-    fname = (gchar *) gtk_file_selection_get_filename(GTK_FILE_SELECTION(w));
+
+    fname = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(w));
 
     if (pref_fsel_unicode)
       gtk_entry_set_text(GTK_ENTRY(pref_unicode), fname);
@@ -675,32 +669,39 @@ pref_set_filename(GtkWidget *w, gpointer data)
     gtk_widget_hide(w);
 }
 
+static void
+handle_filename_response(GtkDialog *d, gint response, gpointer data)
+{
+    switch (response) {
+      case GTK_RESPONSE_ACCEPT:
+        pref_set_filename(GTK_WIDGET(d), data);
+        break;
+      case GTK_RESPONSE_CANCEL:
+        gtk_widget_hide(GTK_WIDGET(d));
+        break;
+    }
+}
+
 static void
 pref_show_fsel_dialog(GtkWidget *w, gpointer data)
 {
-    GtkFileSelection *fs;
-
     pref_fsel_unicode = GPOINTER_TO_INT(data);
 
     if (pref_fsel_dialog == 0) {
-        pref_fsel_dialog = gtk_file_selection_new(0);
+        pref_fsel_dialog = gtk_file_chooser_dialog_new("Glyph Name",
+                                                       GTK_WINDOW(pref_dialog),
+                                                       GTK_FILE_CHOOSER_ACTION_OPEN,
+                                                       GTK_STOCK_CANCEL,
+                                                       GTK_RESPONSE_CANCEL,
+                                                       GTK_STOCK_APPLY,
+                                                       GTK_RESPONSE_ACCEPT,
+                                                       NULL);
         (void) g_signal_connect(G_OBJECT(pref_fsel_dialog), "delete_event",
                                 G_CALLBACK(gtk_widget_hide), 0);
 
-        fs = GTK_FILE_SELECTION(pref_fsel_dialog);
-        gtk_file_selection_hide_fileop_buttons(fs);
-
-        (void) g_signal_connect_object(G_OBJECT(fs->ok_button), "clicked",
-                                       G_CALLBACK(pref_set_filename),
-                                       (gpointer) fs,
-                                       G_CONNECT_SWAPPED);
-        (void) g_signal_connect_object(G_OBJECT(fs->cancel_button),
-                                       "clicked",
-                                       G_CALLBACK(gtk_widget_hide),
-                                       (gpointer) fs,
-                                       G_CONNECT_SWAPPED);
-        gtk_widget_show_all(GTK_DIALOG(pref_fsel_dialog)->vbox);
-        gtk_widget_show_all(GTK_DIALOG(pref_fsel_dialog)->action_area);
+        (void) g_signal_connect(G_OBJECT(pref_fsel_dialog), "response",
+                                G_CALLBACK(handle_filename_response),
+                                NULL);
     }
 
     /*
@@ -977,7 +978,7 @@ pref_save(void)
       fprintf(out, "adobe_name_file %s\n\n",
               options.adobe_name_file);
 
-    fprintf(out, "pixel_size %ld\n\n", options.pixel_size);
+    fprintf(out, "pixel_size %d\n\n", options.pixel_size);
 
     if (options.show_cap_height)
       fprintf(out, "show_cap_height true\n\n");
@@ -1044,11 +1045,6 @@ pref_save(void)
     fprintf(out, "#########################\n\n");
     bdf_save_options(out, &options.font_opts);
     fclose(out);
-
-    /*
-     * Close the preferences dialog.
-     */
-    gtk_widget_hide(pref_dialog);
 }
 
 static void
